#!/bin/bash

# Any failed command will terminate script
set -e

UPGRADE_KERNEL_VERSION="3.14.27"

# Ensure we're running an upgradable kernel, and the SBC3
_kversion="$( cat /proc/version | awk '{print $3}' )"
_board_name="$([ -e /proc/device-tree/model ] && (cat /proc/device-tree/model; echo '';) || (cat /proc/cpuinfo | awk '/^Hardware/ {print $3}'))"

if [ "$_kversion" != "3.6.3" ] && [ "$_kversion" != "3.16.1" ]; then
	echo "This upgrade package is not compatible with your kernel version: $_kversion"
	exit 1
fi

if [ "$_board_name" != "PhidgetSBC3" ]; then
	echo "This upgrade package is not compatible with your board: $_board_name"
	exit 1
fi

read -p "Are you sure you want to upgrade to the $UPGRADE_KERNEL_VERSION kernel? (y/n)" -n 1 -r
echo
if [[ $REPLY =~ ^[Yy]$ ]]
then
	# unlock ro mtd partitions
	insmod mtdrw_${_kversion}.ko

	echo "Upgrading recovery system..."
	flash_eraseall /dev/mtd2
	nandwrite -p /dev/mtd2 imx28-phidget_sbc3.dtb
	flash_eraseall /dev/mtd3
	nandwrite -p /dev/mtd3 uImage.recovery

	echo "Upgrading backup kernel..."
	flash_eraseall /dev/mtd4
	nandwrite -p /dev/mtd4 uImage

	echo "Upgrading backup root filesystem..."
	flash_eraseall /dev/mtd5
	nandwrite -p /dev/mtd5 system_ubi.img

	echo "Upgrading live kernel..."
	flash_eraseall /dev/mtd6
	nandwrite -p /dev/mtd6 uImage

	echo "Installing modules..."
	mv modules.tar.gz /lib/modules/
	(cd /lib/modules/; tar -zxf modules.tar.gz; rm modules.tar.gz; depmod)

	echo "Upgrade completed successfully"
else
	echo "Upgrade cancelled"
	echo
fi